"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
var LinesAction;
(function (LinesAction) {
    LinesAction[LinesAction["addCSharpComment"] = 0] = "addCSharpComment";
    LinesAction[LinesAction["addVBComment"] = 1] = "addVBComment";
    LinesAction[LinesAction["convertToRegularExpression"] = 2] = "convertToRegularExpression";
    LinesAction[LinesAction["cutEachLine"] = 3] = "cutEachLine";
    LinesAction[LinesAction["expandSql"] = 4] = "expandSql";
    LinesAction[LinesAction["listToListFamily"] = 5] = "listToListFamily";
    LinesAction[LinesAction["listToListWrappedComma"] = 6] = "listToListWrappedComma";
    LinesAction[LinesAction["prettySql"] = 7] = "prettySql";
    LinesAction[LinesAction["pdsfToFixedWidth"] = 8] = "pdsfToFixedWidth";
    LinesAction[LinesAction["removeComment"] = 9] = "removeComment";
    LinesAction[LinesAction["searchGoogle"] = 10] = "searchGoogle";
    LinesAction[LinesAction["sortLength"] = 11] = "sortLength";
    LinesAction[LinesAction["sortNormal"] = 12] = "sortNormal";
    LinesAction[LinesAction["unwrapSql"] = 13] = "unwrapSql";
    LinesAction[LinesAction["wrapSqlCSharp"] = 14] = "wrapSqlCSharp";
    LinesAction[LinesAction["wrapSqlVB"] = 15] = "wrapSqlVB";
})(LinesAction || (LinesAction = {}));
function removeBlanks(lines) {
    for (let i = 0; i < lines.length; ++i) {
        if (lines[i].trim() === '') {
            lines.splice(i, 1);
            i--;
        }
    }
}
function getLines(textEditor, startLine, endLine) {
    let results = [];
    for (let i = startLine; i <= endLine; i++) {
        results.push(textEditor.document.lineAt(i).text);
    }
    return results;
}
function addCSharpCommentLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = '//' + lines[i].trim();
    }
}
function addVBCommentLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = "'" + lines[i].trim();
    }
}
function convertToRegularExpressionLogic(lines) {
    let results;
    let result = "";
    let explicitLines = 50;
    for (let i = 0; i < lines.length - 1 && i < explicitLines; ++i) {
        result = result + lines[i].trim().
            split('\\').join('\\\\').
            split('(').join('\\(').
            split(')').join('\\)').
            split('[').join('\\[').
            split(']').join('\\]').
            split('{').join('\\{').
            split('}').join('\\}').
            split('.').join('\\.').
            split('*').join('\\*').
            split('+').join('\\+').
            split('?').join('\\?').
            split('|').join('\\|').
            split('$').join('\\$').
            split('^').join('\\^') +
            '~';
    }
    for (let i = explicitLines; i < lines.length - 1; ++i) {
        result = result + '.*~';
    }
    result = result.
        substring(0, result.length - 1).
        split('~').join('\\r\\n\?\\s\*');
    results = [result];
    return results;
}
function expandSqlLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = ' ' + lines[i];
        lines[i] = lines[i].
            split(' select ').join(' SELECT\r\n').
            split(' from ').join('\r\n FROM ').
            split(' where ').join('\r\n WHERE ').
            split(' and ').join('\r\n and ').
            split(' join ').join('\r\n join ').
            split(' left join ').join('\r\n left join ').
            split(' on ').join('\r\n ON ').
            split(' group by ').join('\r\n GROUP BY ').
            split(' order by ').join('\r\n ORDER BY ').
            split(' SELECT ').join(' SELECT\r\n').
            split(' FROM ').join('\r\n FROM ').
            split(' WHERE ').join('\r\n WHERE ').
            split(' AND ').join('\r\n AND ').
            split(' JOIN ').join('\r\n JOIN ').
            split(' LEFT JOIN ').join('\r\n LEFT JOIN ').
            split(' ON ').join('\r\n ON ').
            split(' GROUP BY ').join('\r\n GROUP BY ').
            split(' ORDER BY ').join('\r\n ORDER BY ').
            split('\r\n\r\n').join('\r\n').
            trim();
    }
    removeBlanks(lines);
    prettySqlLogic(lines);
}
function listToListFamilyLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = "Kristy" + lines[i].trim() + "Mike" + lines[i].trim() + "Jason" + lines[i].trim() + "Mackenzie" + lines[i].trim() + "Logan" + lines[i].trim() + "Lilly" + lines[i].trim() + "Chelsea" + lines[i].trim() + "Piper" + lines[i].trim();
    }
}
function listToListWrappedCommaLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = "'" + lines[i].trim() + "',";
    }
}
function prettySqlLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = ' ' + lines[i];
        lines[i] = lines[i].
            split(' select ').join(' SELECT ').
            split(' distinct ').join(' DISTINCT ').
            split(' as ').join(' AS ').
            split(' from ').join(' FROM ').
            split(' where ').join(' WHERE ').
            split(' and ').join(' AND ').
            split(' join ').join(' JOIN ').
            split(' left join ').join(' LEFT JOIN ').
            split(' on ').join(' ON ').
            split(' group by ').join(' GROUP BY ').
            split(' order by ').join(' ORDER BY ').
            split('\r\n\r\n').join('\r\n').
            trim();
    }
    removeBlanks(lines);
}
function removeCommentLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = lines[i].trim();
        if (lines[i].length > 1 && lines[i][0] === '/' && lines[i][1] === '/') {
            lines[i] = lines[i].substr(2);
        }
        if (lines[i].length > 0 && lines[i][0] === "'") {
            lines[i] = lines[i].substr(1);
        }
    }
}
function searchGoogleLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        vscode.env.openExternal(vscode.Uri.parse(`https://www.google.com/search?q=${lines[i]}`));
    }
}
function makeSorter(algorithm) {
    return function (lines) {
        return lines.sort(algorithm);
    };
}
function sortNormalLogic(lines) {
    var transformers = [];
    transformers.push(makeSorter());
    removeBlanks(lines);
    lines = transformers.reduce((currentLines, transform) => transform(currentLines), lines);
}
function unwrapSqlLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = "//" + lines[i].
            split('sql = "').join('').
            split('sql = sql & "').join('').
            split('sql.Append("').join('').
            split('.Append("').join('').
            split('Append("').join('').
            split('");').join('').
            split('").').join('').
            split('")').join('').
            split('" & ').join('$').
            split(' & "').join('$').
            split('"').join('').
            trim();
    }
}
function wrapSqlCSharpLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = lines[i].trim();
        if (lines[i].length > 1 && lines[i][0] === '/' && lines[i][1] === '/') {
            lines[i] = lines[i].substr(2);
        }
        lines[i] = 'Append(" ' + lines[i] + ' ").';
    }
    if (lines.length > 0) {
        lines[0] = 'sql.' + lines[0];
        lines[lines.length - 1] = lines[lines.length - 1].split(' ").').join(' ");');
    }
}
function wrapSqlVBLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        lines[i] = lines[i].trim();
        if (lines[i].length > 0 && lines[i][0] === "'") {
            lines[i] = lines[i].substr(1);
        }
        lines[i] = 'Append(" ' + lines[i] + ' ").';
    }
    if (lines.length > 0) {
        lines[0] = 'sql.' + lines[0];
    }
}
function sortLengthLogic(lines) {
    lines.sort(function (a, b) {
        // ASC  -> a.length - b.length
        // DESC -> b.length - a.length
        return a.length - b.length || // sort by length, if equal then
            a.localeCompare(b); // sort by dictionary order
    });
    removeBlanks(lines);
}
function cutEachLineLogic(lines) {
    for (let i = 0; i < lines.length; ++i) {
        if (lines[i].length > 0 && lines[i].indexOf("|||") > 0) {
            lines[i] = lines[i].substr(0, lines[i].indexOf("|||"));
        }
        lines[i] = lines[i].trim();
    }
    removeBlanks(lines);
}
function returnLines(textEditor, startLine, endLine, lines) {
    return textEditor.edit(editBuilder => {
        const range = new vscode.Range(startLine, 0, endLine, textEditor.document.lineAt(endLine).text.length);
        editBuilder.replace(range, lines.join('\n'));
    });
}
function linesFunction(linesAction) {
    const textEditor = vscode.window.activeTextEditor;
    if (!textEditor) {
        return undefined;
    }
    var startLine = 0;
    var endLine = textEditor.document.lineCount - 1;
    const selection = textEditor.selection;
    if (!selection.isEmpty) {
        startLine = selection.start.line;
        endLine = selection.end.line;
    }
    let lines = getLines(textEditor, startLine, endLine);
    switch (linesAction) {
        case LinesAction.addCSharpComment: {
            addCSharpCommentLogic(lines);
            break;
        }
        case LinesAction.addVBComment: {
            addVBCommentLogic(lines);
            break;
        }
        case LinesAction.convertToRegularExpression: {
            lines = convertToRegularExpressionLogic(lines);
            break;
        }
        case LinesAction.cutEachLine: {
            cutEachLineLogic(lines);
            break;
        }
        case LinesAction.expandSql: {
            expandSqlLogic(lines);
            break;
        }
        case LinesAction.listToListFamily: {
            listToListFamilyLogic(lines);
            break;
        }
        case LinesAction.listToListWrappedComma: {
            listToListWrappedCommaLogic(lines);
            break;
        }
        case LinesAction.prettySql: {
            prettySqlLogic(lines);
            break;
        }
        case LinesAction.removeComment: {
            removeCommentLogic(lines);
            break;
        }
        case LinesAction.searchGoogle: {
            searchGoogleLogic(lines);
            break;
        }
        case LinesAction.sortLength: {
            sortLengthLogic(lines);
            break;
        }
        case LinesAction.sortNormal: {
            sortNormalLogic(lines);
            break;
        }
        case LinesAction.unwrapSql: {
            unwrapSqlLogic(lines);
            break;
        }
        case LinesAction.wrapSqlCSharp: {
            wrapSqlCSharpLogic(lines);
            break;
        }
        case LinesAction.wrapSqlVB: {
            wrapSqlVBLogic(lines);
            break;
        }
        default: {
            throw new Error();
        }
    }
    return returnLines(textEditor, startLine, endLine, lines);
}
exports.addCSharpComment = () => linesFunction(LinesAction.addCSharpComment);
exports.addVBComment = () => linesFunction(LinesAction.addVBComment);
exports.convertToRegularExpression = () => linesFunction(LinesAction.convertToRegularExpression);
exports.cutEachLine = () => linesFunction(LinesAction.cutEachLine);
exports.expandSql = () => linesFunction(LinesAction.expandSql);
exports.listToListFamily = () => linesFunction(LinesAction.listToListFamily);
exports.listToListWrappedComma = () => linesFunction(LinesAction.listToListWrappedComma);
exports.prettySql = () => linesFunction(LinesAction.prettySql);
exports.pdsfToFixedWidth = () => linesFunction(LinesAction.pdsfToFixedWidth);
exports.removeComment = () => linesFunction(LinesAction.removeComment);
exports.searchGoogle = () => linesFunction(LinesAction.searchGoogle);
exports.sortLength = () => linesFunction(LinesAction.sortLength);
exports.sortNormal = () => linesFunction(LinesAction.sortNormal);
exports.unwrapSql = () => linesFunction(LinesAction.unwrapSql);
exports.wrapSqlCSharp = () => linesFunction(LinesAction.wrapSqlCSharp);
exports.wrapSqlVB = () => linesFunction(LinesAction.wrapSqlVB);
//# sourceMappingURL=helper.js.map